@@ -3,45 +3,44 @@ knitr::opts_chunk$set(echo = TRUE)
 
 ## ---- message=FALSE------------------------------------------------------
 library(Ryacas)
-library(Matrix)
 
 ## ------------------------------------------------------------------------
 L1chr <- diag(4)
 L1chr[2:4, 1] <- "-a"
-L1 <- as.Sym(L1chr)
+L1 <- yac_symbol(L1chr)
 L1
 
 ## ------------------------------------------------------------------------
-L1inv <- Simplify(Inverse(L1))
-K1 <- Simplify(Transpose(L1) * L1)
-V1 <- Simplify(L1inv * Transpose(L1inv))
+L1inv <- solve(L1)
+K1 <- t(L1) %*% L1
+V1 <- L1inv %*% t(L1inv)
 
 ## ---- results="asis"-----------------------------------------------------
 cat(
   "\\begin{align} 
-    K_1 &= ", TeXForm(K1), " \\\\ 
-   V_1 &= ", TeXForm(V1), " 
+    K_1 &= ", tex(K1), " \\\\ 
+   V_1 &= ", tex(V1), " 
   \\end{align}", sep = "")
 
 ## ------------------------------------------------------------------------
 L2chr <- diag(4)
 L2chr[2:4, 1] <- c("-a1", "-a2", "-a3")
-L2 <- as.Sym(L2chr)
+L2 <- yac_symbol(L2chr)
 L2
 Vechr <- diag(4)
 Vechr[cbind(1:4, 1:4)] <- c("w1", "w2", "w2", "w2")
-Ve <- as.Sym(Vechr)
+Ve <- yac_symbol(Vechr)
 Ve
 
 ## ------------------------------------------------------------------------
-L2inv <- Simplify(Inverse(L2))
-K2 <- Simplify(Transpose(L2) * Inverse(Ve) * L2)
-V2 <- Simplify(L2inv * Ve * Transpose(L2inv))
+L2inv <- solve(L2)
+K2 <- t(L2) %*% solve(Ve) %*% L2
+V2 <- L2inv %*% Ve %*% t(L2inv)
 
 ## ---- results="asis"-----------------------------------------------------
 cat(
   "\\begin{align} 
-    K_2 &= ", TeXForm(K2), " \\\\ 
-   V_2 &= ", TeXForm(V2), " 
+    K_2 &= ", tex(K2), " \\\\ 
+   V_2 &= ", tex(V2), " 
   \\end{align}", sep = "")
 
